@@ -17,6 +17,30 @@ use Rose::Object::MakeMethods::Generic
   boolean => 'escape_html_contents',
 );
 
+sub start_html 
+{
+  my($self) = shift; 
+  return '<' . $self->html_element . $self->html_attrs_string . '>';
+}
+
+sub start_xhtml 
+{
+  my($self) = shift; 
+  return '<' . $self->xhtml_element . $self->xhtml_attrs_string . '>';
+}
+
+sub end_html 
+{
+  my($self) = shift; 
+  return '</' . $self->html_element . '>';
+}
+
+sub end_xhtml 
+{
+  my($self) = shift; 
+  return '</' . $self->xhtml_element . '>';
+}
+
 sub html_tag
 {
   my($self) = shift;
